/*=============================================================================
 *
 * Project: a2bstack
 *
 * Copyright (c) 2021 - Analog Devices Inc. All Rights Reserved.
 * This software is subject to the terms and conditions of the license set 
 * forth in the project LICENSE file. Downloading, reproducing, distributing or 
 * otherwise using the software constitutes acceptance of the license. The 
 * software may not be used except as expressly authorized under the license.
 *
 *=============================================================================
 *
 * \file:   palecb.h
 * \author: Mentor Graphics, Embedded Software Division
 * \brief:  Platform specific extensions to the environment control block (ECB).
 *          These include the extensions for the generic Linux platform.
 *
 *=============================================================================
 */

/*============================================================================*/
/** 
 * \defgroup a2bstack_linux_palecb          PAL ECB
 *  
 * Platform specific extensions to the environment control block (ECB).
 * These include the extensions for the generic Linux platform.
 *
 * \{ */
/*============================================================================*/

#ifndef A2B_PALECB_H_
#define A2B_PALECB_H_

/*======================= I N C L U D E S =========================*/

#include "a2b/macros.h"
#include "a2b/ctypes.h"
#include "adi_a2b_busconfig.h"

/*======================= D E F I N E S ===========================*/


/*======================= D A T A T Y P E S =======================*/

A2B_BEGIN_DECLS

/*======================= P U B L I C  P R O T O T Y P E S ========*/

/* Forward definitions */
#if A2B_I2C_ADAPTER == usbi
struct libusb_context;
#endif


typedef struct a2b_PalEcb
{

#ifdef A2B_I2C_ADAPTER_IOCTL
    /** The path to the I2C/I2C device */
    a2b_Char*   i2cDevicePath;

#elif defined(A2B_I2C_ADAPTER_AARDVARK)
    /** If true, the first available adapter regardless of it's unique
     * adapter identifier is opened. By default, this is true.
     */
    a2b_Bool    useFirstAvailable;

    /** If not selecting first available adapter, the available adapter with
     * the matching unique identifier is opened.
     */
    a2b_UInt32  adapterId;

    /** The I2C lock timeout in milliseconds */
    a2b_UInt16  lockTimeout;

#elif defined(A2B_I2C_ADAPTER_USBI)

    /** If true, the first available adapter with a matching vendor/product
     * identifier (VID/PID) is opened by default.
     */
    a2b_Bool    useFirstAvailable;

    /** If not selecting the first available adapter, the available adapter with
     * a matching VID/PID plus bus number and device address is selected.
     */
    a2b_UInt8  busNum;
    a2b_UInt8  devAddr;

    /** The libusb library context */
    struct libusb_context* usbCtx;

    /** The timeout (in milliseconds) control transfers should wait before
     * giving up due to no response being received. For an unlimited
     * timeout zero (0) should be used. The default is 200 msec.
     */
    a2b_UInt32  xferTimeout;
#endif

	/*! Table to get peripheral configuration structure */
	ADI_A2B_NODE_PERICONFIG *pAudioHostDeviceConfig;

    /** The glob search pattern for master/slave plugins */
    a2b_Char*   pluginSearchPattern;

    /**
     * Pointer to opaque client data. This is another way to associate
     * additional data with with the PAL ECB when extending it in some way.
     * It is the client's responsibility to manage the data referenced by
     * this handle.
     */
    a2b_Handle  clientData;
    a2b_Int16 nChainIndex;
    a2b_UInt32 nDeviceInterface;

} a2b_PalEcb;

A2B_END_DECLS

/*======================= D A T A =================================*/

/** \} -- a2bstack_linux_palecb */

#endif /* A2B_PALECB_H_ */
