/*
 * Copyright (c) 2019 Analog Devices, Inc.  All rights reserved.
 *
 * Adapted from the SAM Bare-Metal ("BM") SDK Rel 2.1.0
 *
 * @file	configurations.c
 * @brief	Configures the ADAU1761 CODEC as used on SAM (Sharc Audio Module board).The SRU is configured in system/sru/sru_config.c and is specific to 'adau1761_2ch_i2s_master' usecase
 */

// Drivers for ADAU / SigmaDSP Converters
#include "driver.h"

// Instance of our driver for the ADAU1761 on the SHARC Audio Module board
BM_ADAU_DEVICE adau1761_local;

/**
 * @brief	ADAU1761 CODEC configuration function
 *
 * Configuration script generated in Sigma Studio.
 * The SRU is configured in system/sru/sru_config.c and is specific to 'adau1761_2ch_i2s_master' usecase
 *
 */
int codec_initialize(void) {

	BM_ADAU_RESULT adau1761_result;

    // Initialise the ADAU1761 which is connected to TWI0 as a master
    adau1761_result = adau_initialize(&adau1761_local,
                                      TWI0,
                                      SAM_ADAU1761_I2C_ADDR,
                                      &adau1761_2ch_i2s_master,
                                      ADAU1761_ADDR_BYTES);
    return adau1761_result;
}

