/****************************************************************************
Copyright (c), 2021 - Analog Devices Inc. All Rights Reserved.
This software is proprietary & confidential to Analog Devices, Inc.
and its licensors.
*****************************************************************************
 * @file:    adi_a2b_sys.h
 * @brief:   Contains structures and API prototypes of SigmaStudio Framework.
 * @version: $Revision$
 * @date:    $Date$
 * Developed by: Automotive Software and Systems team, Bangalore, India
*****************************************************************************/
/*! \addtogroup ADI_A2B_SYS
 *  @{
 */

#ifndef __ADI_A2B_SYS_H__
#define __ADI_A2B_SYS_H__

/*=============  I N C L U D E S   =============*/
#include "adi_a2b_hal.h"
#include "adi_a2b_datatypes.h"
/*==============  D E F I N E S  ===============*/
#if CORE1
#define ADI_A2B_ACTIVE_CORE 		(PROCESSOR_SH0)
#else
#define ADI_A2B_ACTIVE_CORE 		(PROCESSOR_ARM)
#endif

#define ADI_A2B_SYS_MEMSIZE_BYTES        (338+2+298+2+48) /*!< Memory required for system component.This is the sum
                                                           of the memory required for ADC,DAC and GPIO. Extra 2 bytes
                                                           are added to word align the address for next unit */

#define E_ADI_A2B_SYS_SUCCESS            (0U)          /*!< Success */
#define E_ADI_A2B_SYS_FAILURE            (-1)          /*!< Failure */
#define E_ADI_A2B_SYS_INSUFFICIENT_MEM   (-2)          /*!< Insufficient memory */
#define E_ADI_A2B_SYS_CORE_SECONDARY     (1U)          /*!< The core has been configured for secondary. The power
                                                           initialization must happen from primary  */

#define MAX_NUMBER_OF_PROCESSORS    (3)	   			/*!< Maximum number of processors */
#define E_PROCESSOR_ARM             (0)	   			/*!< Processor ARM */
#define E_PROCESSOR_SH0             (1)     		/*!< Processor SHARC Core 0 */
#define E_PROCESSOR_SH1             (2)     		/*!< Processor SHARC Core 1 */
#define E_PROCESSOR_HOST            (0x70000000)    /*!< Processor x86 */


#define E_ADI_A2B_SYS_LED10              (0U)          /*!< Enumeration definition for LED 10 */
#define E_ADI_A2B_SYS_LED11              (1U)          /*!< Enumeration definition for LED 11 */
#define E_ADI_A2B_SYS_LED12              (2U)          /*!< Enumeration definition for LED 12 */
#define E_ADI_A2B_SYS_LED13              (3U)          /*!< Enumeration definition for LED 13 */
#define E_ADI_A2B_SYS_LED14              (4U)          /*!< Enumeration definition for LED 14 */
#define E_ADI_A2B_SYS_LED15              (5U)          /*!< Enumeration definition for LED 15 */
#define E_ADI_A2B_SYS_LED16              (6U)          /*!< Enumeration definition for LED 16 */
#define E_ADI_A2B_SYS_LED17              (7U)          /*!< Enumeration definition for LED 17 */

#define E_ADI_A2B_SYS_PB1				(0U)		  /*!< Enumeration definition for push button 1 */
#define E_ADI_A2B_SYS_PB2				(1U)		  /*!< Enumeration definition for push button 2 */
#define E_ADI_A2B_SYS_PB3				(2U)  		  /*!< Enumeration definition for push button 3 */

#define E_ADI_A2B_SYS_SR_48000           (0U)          /*!< Enumeration for a sampling a rate of 48000 Hz */

#define E_ADI_A2B_SYS_POWER_CGUDEV_0    (0U)      /*!< CGU device 0*/
#define E_ADI_A2B_SYS_POWER_CGUDEV_1    (1U)      /*!< CGU device 1*/

#define MAX_CGU_DEVICES                (2U)
#define ADI_A2B_SYS_POWER_CLKIN         (25U  * 1000000U)   /*!< Definition for external input clock frequency (Hz) */

#define ADI_A2B_SYS_POWER_CCLK_MAX      (450U * 1000000U)   /*!< Definition for maximum Core Clock frequency (Hz) */
#define ADI_A2B_SYS_POWER_SYSCLK_MAX    (225U * 1000000U)   /*!< Definition for maximum System Clock frequency (Hz) */

#define ADI_A2B_ADC_MEM_SIZE_BYTES  (ADI_A2B_HAL_ADAU1979_MEMORY_SIZE +         \
                                    sizeof(ADI_A2B_SYS_ADC)                    \
                                    )                            /*!< Memory required by the ADC Device instance.  */

#define E_ADI_A2B_SYS_ADC_SR_48000   (0U)          /*!< Enumeration defiention for ADC sampling rate of 48000 Hz */

#define ADI_A2B_DAC_MEM_SIZE_BYTES   (ADI_A2B_HAL_ADAU1962A_MEMORY_SIZE +        \
                                     sizeof(ADI_A2B_SYS_DAC)                    \
                                     )                           /*!< Memory required by the DAC Device instance.  */

#define E_ADI_A2B_SYS_DAC_SUCCESS    (0U)      /*!< Enumeration definition for DAC success state */
#define E_ADI_A2B_SYS_DAC_FAILED     (-1)      /*!< Enumeration definition for DAC failure state */

#define E_ADI_A2B_SYS_DAC_SR_48000   (0U)    /*!< Enumeration defiention for DAC sampling rate of 48000 Hz */

/* L1 Memory address offset for Sharc 1 via Slave1 port */
#define ADI_SC589_SHARC1_L1_SLAVE1_OFFSET   (0x28000000u)
/* L1 Memory address offset for Sharc 2 via Slave1 port */
#define ADI_SC589_SHARC2_L1_SLAVE1_OFFSET   (0x28800000u)
/* L1 Memory address offset for Sharc 1 via Slave2 port */
#define ADI_SC589_SHARC1_L1_SLAVE2_OFFSET   (0x28400000u)
/* L1 Memory address offset for Sharc 2 via Slave2 port */
#define ADI_SC589_SHARC2_L1_SLAVE2_OFFSET   (0x28C00000u)

/* Sharc L1 private address space start address */
#define ADI_SC589_SHARC_L1_START_ADDR       (0x00240000u)
/* Sharc L1 private address space end address */
#define ADI_SC589_SHARC_L1_END_ADDR         (0x0039FFFFu)

/* Sharc1 L1 Memory start address */
#define ADI_SC589_SHARC1_L1_START_ADDR      (0x28240000u)
/* Sharc1 L1 Memory end address */
#define ADI_SC589_SHARC1_L1_END_ADDR        (0x2879FFFFu)
/* Sharc2 L1 Memory start address */
#define ADI_SC589_SHARC2_L1_START_ADDR      (0x28A40000u)
/* Sharc2 L1 Memory end address */
#define ADI_SC589_SHARC2_L1_END_ADDR        (0x28F9FFFFu)

#define GET_CORE_ID_EN          (true)                           /*!< Get Core ID before address translation */
#define GET_CORE_ID_DIS         (false)                          /*!< Core ID taken as argument */

/*=============  D A T A    T Y P E S   =============*/

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/*! \enum ADI_A2B_RESULT
    Execution status
 */
typedef enum
{
 /*!  Success */
  ADI_A2B_SUCCESS,
 /*!  Failure */
  ADI_A2B_FAILURE,
 /*!  Undefined */
  ADI_A2B_UNDEFINED

}ADI_A2B_RESULT;

 /*! \enum ADI_A2B_PROC_ID
 Enumeration for processor core id.
 */
 typedef enum ADI_A2B_PROC_ID
 {
     PROCESSOR_ARM  = E_PROCESSOR_ARM,
     PROCESSOR_SH0  = E_PROCESSOR_SH0,
     PROCESSOR_SH1  = E_PROCESSOR_SH1,
     PROCESSOR_NONE = E_PROCESSOR_HOST
 }ADI_A2B_PROC_ID;


/*! \enum ADI_A2B_SYS_RESULT
Enumeration for sys result.
*/
typedef enum ADI_A2B_SYS_RESULT
{
    ADI_A2B_SYS_SUCCESS             = E_ADI_A2B_SYS_SUCCESS,
    ADI_A2B_SYS_FAILURE             = E_ADI_A2B_SYS_FAILURE,
    ADI_A2B_SYS_INSUFFICIENT_MEM    = E_ADI_A2B_SYS_INSUFFICIENT_MEM,
    ADI_A2B_SYS_CORE_SECONDARY      = E_ADI_A2B_SYS_CORE_SECONDARY
}ADI_A2B_SYS_RESULT;

/*! \enum ADI_A2B_SYS_PB_NO
SigmaStudio system PB number enumerations.
*/
typedef enum ADI_A2B_SYS_PB_NO
{
    ADI_A2B_SYS_PB1 = E_ADI_A2B_SYS_PB1,       /*!< PB 1 */
    ADI_A2B_SYS_PB2 = E_ADI_A2B_SYS_PB2,       /*!< PB 2 */
    ADI_A2B_SYS_PB3 = E_ADI_A2B_SYS_PB3        /*!< PB 3 */
}ADI_A2B_SYS_PB_NO;


/*! \enum ADI_A2B_SYS_SAMPLERATE
Enumeration for CODEC sampling rate.
*/
typedef enum ADI_A2B_SYS_SAMPLERATE
{
    ADI_A2B_SYS_SR_48000         = E_ADI_A2B_SYS_SR_48000
}ADI_A2B_SYS_SAMPLERATE;

/*! \enum ADI_A2B_SYS_POWER_CGUDEV
Enumeration for CGU device number.
*/
typedef enum ADI_A2B_SYS_POWER_CGUDEV
{
    ADI_A2B_SYS_POWER_CGUDEV_0  = E_ADI_A2B_SYS_POWER_CGUDEV_0,  /*!< The API call succeeded. */
    ADI_A2B_SYS_POWER_CGUDEV_1  = E_ADI_A2B_SYS_POWER_CGUDEV_1   /*!< The API call failed. */
}ADI_A2B_SYS_POWER_CGUDEV;

typedef void* ADI_A2B_SYS_HANDLE;               		   /*!< Type define for system handle */
typedef void (*pushButtonCB)(ADI_A2B_SYS_PB_NO ePBNum); /*!< Type define for PB callback type */

/*! \struct ADI_A2B_SYS_CONFIG
System configuration structure.
*/
typedef struct ADI_A2B_SYS_CONFIG
{
    bool                  bProcMaster;          /*!< Boolean flag indicating if this core is the master. */
    ADI_A2B_SYS_SAMPLERATE eAdcSamplingRate;     /*!< Sampling rate of ADC */
    ADI_A2B_SYS_SAMPLERATE eDacSamplingRate;     /*!< Sampling rate of DAC */
    pushButtonCB          pfPushButtonCB;		/*!< Call back function on PB press */
}ADI_A2B_SYS_CONFIG;

/*=======  P U B L I C   P R O T O T Y P E S  ========*/

/*!< This function allocates memory for the sys components and initializes them. */
ADI_A2B_SYS_RESULT adi_A2B_sys_Init(void *pMemBlock,
        uint32_t const  nMemorySize, ADI_A2B_SYS_CONFIG *pSysConfig);

uint32 adi_a2b_address_translation(uint32 nMemAddr, ADI_A2B_PROC_ID eProcID, bool IsGetId);
void PADS_Init(void);
ADI_A2B_SYS_RESULT adi_a2b_sys_Init(void *pMemBlock, uint32_t const  nMemorySize,ADI_A2B_SYS_CONFIG *pSysConfig);
#ifdef __cplusplus
}
#endif /* __cplusplus */



#endif    /* __ADI_A2B_SYS_H__ */

/*
 *
 * EOF: $URL:  $
 *
*/
