/*=============================================================================
 *
 * Project: a2bstack
 *
 * Copyright (c) 2015 - Analog Devices Inc. All Rights Reserved.
 * This software is subject to the terms and conditions of the license set 
 * forth in the project LICENSE file. Downloading, reproducing, distributing or 
 * otherwise using the software constitutes acceptance of the license. The 
 * software may not be used except as expressly authorized under the license.
 *
 *=============================================================================
 *
 * \file:   pal_info.c
 * \author: Mentor Graphics, Embedded Software Division
 * \brief:  The implementation of version and build information for the
 *          A2B PAL.
 *
 *=============================================================================
 */

/*************************************************************************/
/* DO NOT EDIT THE CODE.  THIS IS GENERATED DURING THE BUILD PROCESS.    */
/*       (modify the pal_info.in file if changes are needed)             */
/*************************************************************************/

/*======================= I N C L U D E S =========================*/

#include "a2b/palversion.h"

/*======================= D E F I N E S ===========================*/

/*======================= L O C A L  P R O T O T Y P E S  =========*/

/*======================= D A T A  ================================*/

/*======================= C O D E =================================*/

/*!****************************************************************************
*
*  \b              pal_infoGetVersion
*
*  Optionally returns the A2B PAL stack major, minor, and release version.
*  This is the version assigned to the PAL when it's built and is encoded
*  in the binary library.
*
*  \param   [in,out]    major   The major version of the PAL. If A2B_NULL
*                               is passed to this function then nothing
*                               will be stored.
*  
*  \param   [in,out]    minor   The minor version of the PAL. If A2B_NULL
*                               is passed to this function then nothing
*                               will be stored.
*  
*  \param   [in,out]    release The release version of the PAL. If A2B_NULL
*                               is passed to this function then nothing
*                               will be stored.
*
*  \pre     None
*
*  \post    None
*
*  \return  None
*
******************************************************************************/
void
pal_infoGetVersion
    (
    a2b_UInt32*  major,
    a2b_UInt32*  minor,
    a2b_UInt32*  release
    )
{
    /*************************************************************************/
    /* DO NOT EDIT THE CODE.  THIS IS GENERATED DURING THE BUILD PROCESS.    */
    /*       (modify the pal_info.in file if changes are needed)             */
    /*************************************************************************/

    if ( A2B_NULL != major )
    {
        *major = A2B_PAL_VER_MAJOR;
    }

    if ( A2B_NULL != minor )
    {
        *minor = A2B_PAL_VER_MINOR;
    }

    if ( A2B_NULL != release )
    {
        *release = A2B_PAL_VER_RELEASE;
    }

    /*************************************************************************/
    /* DO NOT EDIT THE CODE.  THIS IS GENERATED DURING THE BUILD PROCESS.    */
    /*       (modify the pal_info.in file if changes are needed)             */
    /*************************************************************************/

} /* pal_infoGetVersion */


/*!****************************************************************************
*
*  \b              pal_infoGetBuild
*
*  Optionally returns information about the PAL build including build number,
*  date, owner, source revision, and host machine that did the build.
*  
*  \param   [in,out]    buildNum    An incrementing build number. If A2B_NULL
*                                   is passed to this function then nothing
*                                   will be stored.
*  
*  \param   [in,out]    buildDate   The date the library was built. If A2B_NULL
*                                   is passed to this function then nothing
*                                   will be stored. 
*  
*  \param   [in,out]    buildOwner  The owner/user who built this software. If
*                                   A2B_NULL is passed to this function then
*                                   nothing will be stored.
*  
*  \param   [in,out]    buildSrcRev The source control revision associated with
*                                   the stack being built. If A2B_NULL is
*                                   passed to this function then nothing
*                                   will be stored.
*  
*  \param   [in,out]    buildHost   The host machine where the A2B stack was
*                                  built. If A2B_NULL is passed to this
*                                  function then nothing will be stored.
*
*  \pre     None
*
*  \post    None
*
*  \return  None
*
******************************************************************************/
void
pal_infoGetBuild
    (
    a2b_UInt32*             buildNum,
    const a2b_Char** const  buildDate,
    const a2b_Char** const  buildOwner,
    const a2b_Char** const  buildSrcRev,
    const a2b_Char** const  buildHost
    )
{
    /*************************************************************************/
    /* DO NOT EDIT THE CODE.  THIS IS GENERATED DURING THE BUILD PROCESS.    */
    /*       (modify the pal_info.in file if changes are needed)             */
    /*************************************************************************/

    if ( A2B_NULL != buildNum )
    {
        *buildNum = 15;
    }
    
    if ( A2B_NULL != buildDate )
    {
        *buildDate = "Tue 20 Dec 2016 12:43:49 PM EST";
    }
    
    if ( A2B_NULL != buildOwner )
    {
        *buildOwner = "kfurge";
    }
    
    if ( A2B_NULL != buildSrcRev )
    {
        *buildSrcRev = "65a85437a47d42cbfb3931c921b5d3652e81d464";
    }
    
    if ( A2B_NULL != buildHost )
    {
        *buildHost = "kfurge-HP-EliteBook-8460p";
    }

    /*************************************************************************/
    /* DO NOT EDIT THE CODE.  THIS IS GENERATED DURING THE BUILD PROCESS.    */
    /*       (modify the pal_info.in file if changes are needed)             */
    /*************************************************************************/

} /* pal_infoGetBuild */


