/*******************************************************************************
Copyright (c) 2023 - Analog Devices Inc. All Rights Reserved.
This software is proprietary & confidential to Analog Devices, Inc.
and its licensors.
******************************************************************************/

/*======================= I N C L U D E S =========================*/
#include <a2bapp_codec_init.h>
#include "pal_i2c.h"
#include <linux/i2c.h>
#include <stdio.h>

/*======================= D E F I N E S ===========================*/
#define A2B_CONF_CODEC_I2C_DEVICE_PATH    "/dev/i2c-1" 

/*======================= L O C A L  P R O T O T Y P E S  =========*/
/*======================= D A T A  ================================*/
a2b_Byte I2C_BUF[3u];
a2b_Byte dac_ctrl_reg;
a2b_Byte adc_ctrl_reg;
struct Config_Table
{
	a2b_UInt8 Reg_Add;
	a2b_UInt8  Value;
};
struct Config_Table Config_array_DAC[24] = {
		   	    {     ADAU1962_PDN_CTRL_1,		0xa4},
		   	    {     ADAU1962_PDN_CTRL_2,	    0x00},
		   	    {     ADAU1962_PDN_CTRL_3,	    0x00},
		   	    {     ADAU1962_DAC_CTRL0,		0x19},
		   	    {     ADAU1962_DAC_CTRL1,		0x62},
		   	    {     ADAU1962_DAC_CTRL2,		0x04},
		   	    {     ADAU1962_DAC_MUTE1,	    0x00},
		   	    {     ADAU1962_DAC_MUTE2,	    0x00},
		   	    {     ADAU1962_MSTR_VOL,		0x00},
			    {     ADAU1962_DAC1_VOL,	    0x00},
			    {     ADAU1962_DAC2_VOL,		0x00},
				{     ADAU1962_DAC3_VOL,		0x00},
				{     ADAU1962_DAC4_VOL,		0x00},
				{     ADAU1962_DAC5_VOL,		0x00},
				{     ADAU1962_DAC6_VOL,		0x00},
				{     ADAU1962_DAC7_VOL,		0x00},
				{     ADAU1962_DAC8_VOL,	    0x00},
				{     ADAU1962_DAC9_VOL,		0x00},
				{     ADAU1962_DAC10_VOL,		0x00},
				{     ADAU1962_DAC11_VOL,		0x00},
				{     ADAU1962_DAC12_VOL,		0x00},
				{     ADAU1962_PAD_STRGTH,		0x02},
				{     ADAU1962_DAC_PWR1,		0xaa},
				{     ADAU1962_DAC_PWR2,		0xaa}
};
struct Config_Table Config_array_ADC[13] = {

		 {ADAU1979_REG_BLOCK_POWER_SAI	,	0xb0},
		 {ADAU1979_REG_SAI_CTRL0		,	0x5a},/*I2S 48kHz*/
		 {ADAU1979_REG_SAI_CTRL1		,	0x08},
		 {ADAU1979_REG_CMAP12			,	0x10},
		 {ADAU1979_REG_CMAP34			,	0x32},
		 {ADAU1979_REG_SAI_OVERTEMP		,	0xf0},
		 {ADAU1979_REG_POST_ADC_GAIN1 	,	0xA0},
		 {ADAU1979_REG_POST_ADC_GAIN2 	,	0xA0},
		 {ADAU1979_REG_POST_ADC_GAIN3 	,	0xA0},
		 {ADAU1979_REG_POST_ADC_GAIN4 	,	0xA0},
		 {ADAU1979_REG_MISC_CONTROL		,	0x12},
		 {ADAU1979_REG_DC_HPF_CAL		,	0x00},
		 {ADAU1979_REG_BLOCK_POWER_SAI	,	0xbf}
};
a2b_Byte Config_read_DAC[24];
a2b_Byte Config_read_ADC[13];
/***********PIN MUX***************************************/
#define SPI1_CLK_PORTA_MUX  ((uint32_t) ((uint32_t) 1<<20))
#define SPI1_MISO_PORTA_MUX  ((uint32_t) ((uint32_t) 1<<22))
#define SPI1_MOSI_PORTA_MUX  ((uint32_t) ((uint32_t) 1<<24))
#define SPI1_SEL1_PORTA_MUX  ((uint32_t) ((uint32_t) 1<<26))
#define SPI1_SEL2_PORTB_MUX  ((uint32_t) ((uint32_t) 1<<20))
#define TWI2_SCL_PORTA_MUX  ((uint32_t) ((uint32_t) 0<<28))
#define TWI2_SDA_PORTA_MUX  ((uint32_t) ((uint32_t) 0<<30))

#define SPI1_CLK_PORTA_FER  ((uint32_t) ((uint32_t) 1<<10))
#define SPI1_MISO_PORTA_FER  ((uint32_t) ((uint32_t) 1<<11))
#define SPI1_MOSI_PORTA_FER  ((uint32_t) ((uint32_t) 1<<12))
#define SPI1_SEL1_PORTA_FER  ((uint32_t) ((uint32_t) 1<<13))
#define SPI1_SEL2_PORTB_FER  ((uint32_t) ((uint32_t) 1<<10))
#define TWI2_SCL_PORTA_FER  ((uint32_t) ((uint32_t) 1<<14))
#define TWI2_SDA_PORTA_FER  ((uint32_t) ((uint32_t) 1<<15))
/*======================= C O D E =================================*/
a2b_UInt32 SWITCH_CONFIG(a2b_Handle hnd)
{
	a2b_UInt32 result;
	struct pal_I2cDcb* dcb;
	dcb = (struct pal_I2cDcb*)hnd;
/*********Switch config************/
	I2C_BUF[0] = (a2b_UInt8)0x12;
	I2C_BUF[1] = (a2b_UInt8)0x25;
	result = pal_i2cWrite(dcb,0x22,2u,I2C_BUF);

	I2C_BUF[0] = (a2b_UInt8)0x13;
	I2C_BUF[1] = (a2b_UInt8)0xFD;
	result = pal_i2cWrite(dcb,0x22,2u,I2C_BUF);

	I2C_BUF[0] = (a2b_UInt8)0x00;
	I2C_BUF[1] = (a2b_UInt8)0x18;
	result = pal_i2cWrite(dcb,0x22,2u,I2C_BUF);

	I2C_BUF[0] = (a2b_UInt8)0x01;
	I2C_BUF[1] = (a2b_UInt8)0x00;
	result = pal_i2cWrite(dcb,0x22,2u,I2C_BUF);

	return result;

}
a2b_HResult ADAU_1962_PLL_Init(a2b_Handle hnd)
{
	struct pal_I2cDcb* dcb;
	dcb = (struct pal_I2cDcb*)hnd;
	a2b_HResult status;
	a2b_UInt32 delay = 0xffff;
	I2C_BUF[0] = (a2b_UInt8)0x00;
	I2C_BUF[1] = (a2b_UInt8)0x01;
	status = pal_i2cWrite(dcb,0x04,2u,I2C_BUF);
	while(delay--)
	{
		asm("nop;");
	}
	I2C_BUF[0] = (a2b_UInt8)0x01;
	I2C_BUF[1] = (a2b_UInt8)0xaa;
	status = pal_i2cWrite(dcb,0x04,2u,I2C_BUF);
	delay = 0xffff;
	while(delay--)
	{
		asm("nop;");
	}
	I2C_BUF[0] = (a2b_UInt8)0x01;
	status = pal_i2cWriteRead(dcb,0x04,1u,I2C_BUF,1u,&dac_ctrl_reg);
	delay = 0xffff;
	while(delay--)
	{
		asm("nop;");
	}
	/********wait for PLL Lock***********/
	while(!((dac_ctrl_reg & 0x4)>>2)  )
	{
		I2C_BUF[0] = (a2b_UInt8)0x01;
		status=pal_i2cWriteRead(dcb,0x04,1u,I2C_BUF,1u,&dac_ctrl_reg);
	}
	I2C_BUF[0] = (a2b_UInt8)0x00;
	I2C_BUF[1] = (a2b_UInt8)0x75;
	status = pal_i2cWrite(dcb,0x04,2u,I2C_BUF);
	delay = 0xffff;
	while(delay--)
	{
		asm("nop;");
	}
	return status;
}

a2b_UInt32 ADAU_1962_init(a2b_Handle hnd)
{
	a2b_UInt32 result;
	struct pal_I2cDcb* dcb;
	dcb = (struct pal_I2cDcb*)hnd;
	result = ADAU_1962_PLL_Init(dcb);
	if(result != 0)
	{
		return result;
	}
	for(a2b_UInt8 i=0;i<24;i++)
	{
		I2C_BUF[0] = Config_array_DAC[i].Reg_Add;
		I2C_BUF[1] = Config_array_DAC[i].Value;
		result = pal_i2cWrite(dcb,0x04,2u,I2C_BUF);
		/*********test code**********************/
		I2C_BUF[0] = Config_array_DAC[i].Reg_Add;
		result = pal_i2cWriteRead(dcb,0x04,1u,I2C_BUF,1u,&Config_read_DAC[i]);
		if(Config_array_DAC[i].Value!= Config_read_DAC[i])
		{
			printf("\n Configuring ADAU_1962 failed\n");
			return CODAC_FAILED;
		}
		/********unmute all DAC ch********************/
		I2C_BUF[0] = 0x06;
		I2C_BUF[1] = 0x18;
		result = pal_i2cWrite(dcb,0x04,2u,I2C_BUF);
	}
	return result;
}
a2b_HResult ADAU_1979_PLL_Init(a2b_Handle hnd)
{
	struct pal_I2cDcb* dcb;
	dcb = (struct pal_I2cDcb*)hnd;
	a2b_HResult status;
	a2b_UInt32 delay = 0xffff;
	/***********master power***********/
	I2C_BUF[0] = (a2b_UInt8)0x00;
	I2C_BUF[1] = (a2b_UInt8)0x01;
	status = pal_i2cWrite(dcb,0x11,2u,I2C_BUF);
	while(delay--)
	{
		asm("nop;");
	}
	/*********PLL Config for 1979**********/
	I2C_BUF[0] = (a2b_UInt8)0x01;
	I2C_BUF[1] = (a2b_UInt8)0x43;
	status = pal_i2cWrite(dcb,0x11,2u,I2C_BUF);
	delay = 0xffff;
	while(delay--)
	{
		asm("nop;");
	}
	/*******Read PLL register**************/
	I2C_BUF[0] = (a2b_UInt8)0x01;
	status = pal_i2cWriteRead(dcb,0x11,1u,I2C_BUF,1u,&adc_ctrl_reg);
	delay = 0xffff;
	while(delay--)
	{
		asm("nop;");
	}
	/***************wait for PLL Lock*******/
	while(!((adc_ctrl_reg & 0x80)>>7)  )
	{
		I2C_BUF[0] = (a2b_UInt8)0x01;
		status=pal_i2cWriteRead(dcb,0x11,1u,I2C_BUF,1u,&adc_ctrl_reg);
	}
	/*********PLL Config for 1979**********/
	I2C_BUF[0] = (a2b_UInt8)0x01;
	I2C_BUF[1] = (a2b_UInt8)0x53;
	status = pal_i2cWrite(dcb,0x11,2u,I2C_BUF);
	delay = 0xffff;
	while(delay--)
	{
		asm("nop;");
	}
	return status;
}
a2b_UInt32 ADAU_1979_init(a2b_Handle hnd)
{
	a2b_UInt32 result;
	struct pal_I2cDcb* dcb;
	dcb = (struct pal_I2cDcb*)hnd;
	result = ADAU_1979_PLL_Init(dcb);
	if(result != 0)
	{
		return result;
	}
	/*****Static configuration write reg val*******/
	for(a2b_UInt8 i=0;i<13;i++)
	{
		I2C_BUF[0] = Config_array_ADC[i].Reg_Add;
		I2C_BUF[1] = Config_array_ADC[i].Value;
		result = pal_i2cWrite(dcb,0x11,2u,I2C_BUF);
		/************test code*******************/
		I2C_BUF[0] = Config_array_ADC[i].Reg_Add;
		result = pal_i2cWriteRead(dcb,0x11,1u,I2C_BUF,1u,&Config_read_ADC[i]);
		if(Config_array_ADC[i].Value!= Config_read_ADC[i])
		{
			printf("\n Configuring ADAU_1979 failed\n");
			return CODAC_FAILED;
		}
	}
	/**********Unmute all ADC channels************/
	I2C_BUF[0] = 0x0e;
	I2C_BUF[1] = 0x02;
	result = pal_i2cWrite(dcb,0x11,2u,I2C_BUF);
	return result;
}
a2b_Handle ADC_DAC_I2C_OPEN(void)
{
	struct pal_I2cDcb* dcb;
	A2B_ECB        ecb;
	ecb.palEcb.i2cDevicePath = A2B_CONF_CODEC_I2C_DEVICE_PATH;
	dcb = pal_i2cOpen(A2B_I2C_ADDR_FMT_7BIT,0,&ecb);
	return dcb;
}
a2b_UInt32 ADC_DAC_I2C_CLOSE(a2b_Handle hnd)
{
	struct pal_I2cDcb* dcb;
	dcb = (struct pal_I2cDcb*)hnd;
	a2b_UInt32 result = pal_i2cClose(dcb);
	return result;
}
