/*=============================================================================
 *
 * Project: a2bstack
 *
 * Copyright (c) 2015 - Analog Devices Inc. All Rights Reserved.
 * This software is subject to the terms and conditions of the license set 
 * forth in the project LICENSE file. Downloading, reproducing, distributing or 
 * otherwise using the software constitutes acceptance of the license. The 
 * software may not be used except as expressly authorized under the license.
 *
 *=============================================================================
 *
 * \file:   pal_memmgr.h
 * \author: Mentor Graphics, Embedded Software Division
 * \brief:  Defines the PAL API for the memory management service based on
 *          Linux malloc/free.
 *
 *=============================================================================
 */

/*============================================================================*/
/** 
 * \defgroup a2bstack_pal_memmgr        PAL MemMgr Module 
 *  
 * Defines the PAL API for the memory management service based on
 * Linux malloc/free.
 *  
 * \{ */
/*============================================================================*/

#ifndef A2B_PAL_MEMMGR_H_
#define A2B_PAL_MEMMGR_H_

/*======================= I N C L U D E S =========================*/

#include "a2b/macros.h"
#include "a2b/ctypes.h"
#include "a2b/ecb.h"
#include "a2b/features.h"

/* A2B_FEATURE_MEMORY_MANAGER_DOXY is only to allow doxygen to document the code */
#if !defined(A2B_FEATURE_MEMORY_MANAGER) || defined(A2B_FEATURE_MEMORY_MANAGER_DOXY)

/*======================= D E F I N E S ===========================*/

/*======================= D A T A T Y P E S =======================*/

A2B_BEGIN_DECLS

/*======================= P U B L I C  P R O T O T Y P E S ========*/

A2B_EXPORT A2B_DSO_LOCAL a2b_HResult pal_memMgrInit(A2B_ECB* ecb);

A2B_EXPORT A2B_DSO_LOCAL a2b_Handle pal_memMgrOpen(a2b_Byte*    heap,
                                                   a2b_UInt32   heapSize);

A2B_EXPORT A2B_DSO_LOCAL void* pal_memMgrMalloc(a2b_Handle hnd,
                                                a2b_UInt32 size);

A2B_EXPORT A2B_DSO_LOCAL void pal_memMgrFree(a2b_Handle hnd, 
                                             void*      p);

A2B_EXPORT A2B_DSO_LOCAL a2b_HResult pal_memMgrClose(a2b_Handle hnd);

A2B_EXPORT A2B_DSO_LOCAL a2b_HResult pal_memMgrShutdown(A2B_ECB* ecb);

A2B_END_DECLS

/*======================= D A T A =================================*/

#endif  /* A2B_FEATURE_MEMORY_MANAGER */

/** \} -- a2bstack_pal_memmgr */

#endif /* A2B_PAL_MEMMGR_H_ */
