/*******************************************************************************
Copyright (c) 2014 - Analog Devices Inc. All Rights Reserved.
This software is proprietary & confidential to Analog Devices, Inc.
and its licensors.
******************************************************************************
 * @file:    adi_a2b_sys.c
 * @brief:   System component APIs are defined in this file
 * @version: $Revision: 66678 $
 * @date:    $Date: 2021-08-04 06:49:25 -0400 (Wed, 04 Aug 2021) $
 * Developed by: Automotive Software and Systems team, Bangalore, India
*****************************************************************************/
/*! \addtogroup ADI_A2B_SYS
 *  @{
 */

/*============= I N C L U D E S =============*/

#include "adi_a2b_sys.h"
#include <sys/adi_core.h>

/*============= D E F I N E S =============*/
#if defined(__ADSPSC589__)
#define LED10_PORT    (ADI_A2B_HAL_GPIO_PORT_E)     /*!< HPC EZ-Kit uses port E for LED 10 */
#define LED10_PIN     (ADI_A2B_HAL_GPIO_PIN_13)     /*!< HPC EZ-Kit uses pin 13 for LED 10 */
#define LED11_PORT    (ADI_A2B_HAL_GPIO_PORT_E)     /*!< HPC EZ-Kit uses port E for LED 11 */
#define LED11_PIN     (ADI_A2B_HAL_GPIO_PIN_14)     /*!< HPC EZ-Kit uses pin 14 for LED 11 */
#define LED12_PORT    (ADI_A2B_HAL_GPIO_PORT_E)     /*!< HPC EZ-Kit uses port E for LED 12 */
#define LED12_PIN     (ADI_A2B_HAL_GPIO_PIN_15)     /*!< HPC EZ-Kit uses pin 15 for LED 12 */
#elif defined(__ADSPSC584__)
#define LED10_PORT    (ADI_A2B_HAL_GPIO_PORT_E)     /*!< LPC EZ-Kit uses port E for LED 10 */
#define LED10_PIN     (ADI_A2B_HAL_GPIO_PIN_1)      /*!< LPC EZ-Kit uses pin 1 for LED 10 */
#define LED11_PORT    (ADI_A2B_HAL_GPIO_PORT_E)     /*!< LPC EZ-Kit uses port E for LED 11 */
#define LED11_PIN     (ADI_A2B_HAL_GPIO_PIN_2)      /*!< LPC EZ-Kit uses pin 2 for LED 11 */
#define LED12_PORT    (ADI_A2B_HAL_GPIO_PORT_E)     /*!< LPC EZ-Kit uses port E for LED 12 */
#define LED12_PIN     (ADI_A2B_HAL_GPIO_PIN_3)      /*!< LPC EZ-Kit uses pin 3 for LED 12 */
#define LED13_PORT    (ADI_A2B_HAL_GPIO_PORT_E)     /*!< LPC EZ-Kit uses port E for LED 13 */
#define LED13_PIN     (ADI_A2B_HAL_GPIO_PIN_4)      /*!< LPC EZ-Kit uses pin 4 for LED 13 */
#define LED14_PORT    (ADI_A2B_HAL_GPIO_PORT_E)     /*!< LPC EZ-Kit uses port E for LED 14 */
#define LED14_PIN     (ADI_A2B_HAL_GPIO_PIN_5)      /*!< LPC EZ-Kit uses pin 5 for LED 14 */
#define LED15_PORT    (ADI_A2B_HAL_GPIO_PORT_E)     /*!< LPC EZ-Kit uses port E for LED 15 */
#define LED15_PIN     (ADI_A2B_HAL_GPIO_PIN_6)      /*!< LPC EZ-Kit uses pin 6 for LED 15 */
#define LED16_PORT    (ADI_A2B_HAL_GPIO_PORT_E)     /*!< LPC EZ-Kit uses port E for LED 16 */
#define LED16_PIN     (ADI_A2B_HAL_GPIO_PIN_7)      /*!< LPC EZ-Kit uses pin 7 for LED 16 */
#define LED17_PORT    (ADI_A2B_HAL_GPIO_PORT_E)     /*!< LPC EZ-Kit uses port E for LED 17 */
#define LED17_PIN     (ADI_A2B_HAL_GPIO_PIN_8)      /*!< LPC EZ-Kit uses pin 8 for LED 17 */
#endif

#define PORT_CODEC_RESET    (ADI_A2B_HAL_GPIO_PORT_A)            /*!< Port used for resetting the ADC and DAC. This is
                                                                     a hard wired port number for CODEC resetting. */
#define PIN_CODEC_RESET     (ADI_A2B_HAL_GPIO_PIN_14)            /*!< Pin used for resetting the ADC and DAC. This
                                                                     is a hard wired pin number for CODEC resetting. */
#ifndef _TESSY_
#define WAIT_CLOCK_CYCLES(n)      \
        do                        \
        {                         \
			do                    \
			{                     \
            (n)--;                \
			}while((n)>0);        \
        }while(0)
#else	/* _TESSY_ */
#define WAIT_CLOCK_CYCLES(n)      \
			do                    \
			{                     \
            (n)--;                \
			}while((n)>0);
#endif	/* _TESSY_ */

#define CODEC_RESET_DELAY    (100000U)
/*============= D A T A =============*/


/*============= C O D E =============*/

/*
** Function Prototype section
** (static-scoped functions)
*/

static ADI_PWR_RESULT CheckClock(ADI_A2B_SYS_POWER_CONFIG *pSysPowerConfig);
static ADI_PWR_RESULT ConfigureClocks(ADI_A2B_SYS_POWER_CGUDEV eCGUDev);
static ADI_PWR_RESULT SetClkDiv(ADI_A2B_SYS_POWER_CGUDEV eCGUDev);
static ADI_A2B_SYS_RESULT LED_Init(void);
#ifndef __ADSPSC59x__
static ADI_A2B_SYS_RESULT LED_Update(ADI_A2B_SYS_LED_NO eLEDNo, bool bLEDOn);
#endif


#ifndef __ADSPSC59x__
/*!
   @brief        This function can be used to turnOn/turnOff different LEDs
   @param        eLedNo       LED no enumeration.
   @param        bLedOn       Boolean flag for turning LED on if true
   @return       Return code of ADI_A2B_SYS_RESULT type.
                   - #ADI_A2B_SYS_SUCCESS                   : LED updated successfully
                   - #ADI_A2B_SYS_FAILURE                   : LED updation failed

   <b> Global Variables Used: <b>
                None

  @note            None.
*/
ADI_A2B_SYS_RESULT adi_a2b_sys_LEDUpdate(ADI_A2B_SYS_LED_NO eLedNo, bool bLedOn)
{
	ADI_A2B_SYS_RESULT eLedRes;

    eLedRes = LED_Update(eLedNo, bLedOn);

    return (eLedRes);
}
#endif

#ifndef __ADSPSC59x__
/*!
    @brief      This function is used to initialize the various clocks in the system
                including the core and system clocks.
    @param      pSysPowerConfig  Configuration structure for power management.
    @return     return code of ADI_A2B_SYS_POWER_RESULT type.
                    - ADI_A2B_SYS_POWER_SUCCESS  :  The API call is success.
                    - ADI_A2B_SYS_POWER_FAILED   :  The API call is failure.

    <b> Global Variables Used: <b>
                None.

   @note        None.
 */

ADI_A2B_SYS_RESULT Power_Init(ADI_A2B_SYS_POWER_CONFIG *pSysPowerConfig)
{
	ADI_PWR_RESULT  eResult = ADI_PWR_FAILURE;

    /* Set the clocks for cores and system clock */
    if(pSysPowerConfig->bSetCoreSysClk == true)
    {
		if(((uint32_t)pSysPowerConfig->eCGUDev > MAX_CGU_DEVICES) || (pSysPowerConfig->nCoreClk < pSysPowerConfig->nSysClk))
		{
			eResult = ADI_PWR_FAILURE;
		}

		if(eResult == ADI_PWR_SUCCESS)
		{
			eResult = adi_pwr_Init((uint32_t)pSysPowerConfig->eCGUDev, ADI_A2B_SYS_POWER_CLKIN);
		}

		if(eResult == ADI_PWR_SUCCESS)
		{
			eResult = adi_pwr_SetPowerMode((uint32_t)pSysPowerConfig->eCGUDev, ADI_PWR_MODE_FULL_ON);
		}

		if(eResult == ADI_PWR_SUCCESS)
		{
			eResult = adi_pwr_SetFreq((uint32_t)pSysPowerConfig->eCGUDev, pSysPowerConfig->nCoreClk,
									   pSysPowerConfig->nSysClk
									  );
		}

		if(eResult == ADI_PWR_SUCCESS)
		{
            eResult = CheckClock(pSysPowerConfig);
		}
    }
    else
    {
    	eResult = ConfigureClocks(pSysPowerConfig->eCGUDev);
    }

    return ((eResult==ADI_PWR_SUCCESS) ? ADI_A2B_SYS_SUCCESS : ADI_A2B_SYS_FAILURE);
}


/*!
    @brief     Function to check the set clock values.
    @param     pSysPowerConfig  Configuration structure for power management.se.
    @return    Return code of ADI_PWR_RESULT type.
                    - ADI_PWR_SUCCESS  :  The call to this function is successful.
                    - ADI_PWR_FAILURE  :  The call to this function failed.

    <b> Global Variables Used: <b>
                None.

   @note        None.
*/

static ADI_PWR_RESULT CheckClock(ADI_A2B_SYS_POWER_CONFIG *pSysPowerConfig)
{
    uint32_t    fcclk    = 0U;
    uint32_t    fsysclk  = 0U;
    uint32_t    fsclk0   = 0U;
    uint32_t    fsclk1   = 0U;
	ADI_PWR_RESULT  eResult = ADI_PWR_SUCCESS;

    eResult = adi_pwr_GetCoreFreq((uint32_t)pSysPowerConfig->eCGUDev, &fcclk);
	eResult = adi_pwr_GetSystemFreq((uint32_t)pSysPowerConfig->eCGUDev, &fsysclk, &fsclk0, &fsclk1);


	if(eResult == ADI_PWR_SUCCESS)
	{
		if((fcclk < (pSysPowerConfig->nCoreClk-ADI_A2B_SYS_POWER_CLKIN)) ||
		   (fsysclk < (pSysPowerConfig->nSysClk-ADI_A2B_SYS_POWER_CLKIN)))
		{
			eResult = ADI_PWR_FAILURE;
		}
	}

	return eResult;
}

/*!
    @brief      Function to configure the various clocks in the system.
    @param      eCGUDev  The CGU device to use.
    @return     return code of ADI_PWR_RESULT type.
                    - ADI_PWR_SUCCESS  :  The call to this function is successful.
                    - ADI_PWR_FAILURE  :  The call to this function failed.

    <b> Global Variables Used: <b>
                None.

   @note        None.
*/

static ADI_PWR_RESULT ConfigureClocks(ADI_A2B_SYS_POWER_CGUDEV eCGUDev)
{
	ADI_PWR_RESULT  eResult = ADI_PWR_FAILURE;

    eResult = adi_pwr_Init((uint32_t)eCGUDev, ADI_A2B_SYS_POWER_CLKIN);

    eResult = adi_pwr_SetPllControlRegister((uint32_t)eCGUDev, ADI_PWR_PLL_CTL_ENABLE, 1);

    eResult = adi_pwr_SetPllControlRegister((uint32_t)eCGUDev, ADI_PWR_PLL_CTL_EXIT_ACTIVE, 1);

	eResult = adi_pwr_SetClkControlRegister((uint32_t)eCGUDev, ADI_PWR_CLK_CTL_MSEL, 28);

	eResult = SetClkDiv(eCGUDev);

	eResult = adi_pwr_ConfigCduInputClock(ADI_PWR_CDU_CLKIN_1, ADI_PWR_CDU_CLKOUT_5);

    return eResult;
}


/*!
    @brief      Function to set the various clock dividers.
    @param      eCGUDev  The CGU device to use.
    @return     return code of ADI_PWR_RESULT type.
                    - ADI_PWR_SUCCESS  :  The call to this function is successful.
                    - ADI_PWR_FAILURE  :  The call to this function failed.

    <b> Global Variables Used: <b>
                None.

   @note        None.
*/
static ADI_PWR_RESULT SetClkDiv(ADI_A2B_SYS_POWER_CGUDEV eCGUDev)
{
	ADI_PWR_RESULT  eResult = ADI_PWR_SUCCESS;

	eResult = adi_pwr_SetClkDivideRegister((uint32_t)eCGUDev, ADI_PWR_CLK_DIV_CSEL, 2);

	eResult = adi_pwr_SetClkDivideRegister((uint32_t)eCGUDev, ADI_PWR_CLK_DIV_S0SEL, 2);

	eResult = adi_pwr_SetClkDivideRegister((uint32_t)eCGUDev, ADI_PWR_CLK_DIV_SYSSEL, 4);

	eResult = adi_pwr_SetClkDivideRegister((uint32_t)eCGUDev, ADI_PWR_CLK_DIV_S1SEL, 2);

	eResult = adi_pwr_SetClkDivideRegister((uint32_t)eCGUDev, ADI_PWR_CLK_DIV_DSEL, 2);

	eResult = adi_pwr_SetClkDivideRegister((uint32_t)eCGUDev, ADI_PWR_CLK_DIV_OSEL, 4);

	return eResult;
}

/*!
    @brief      This function sets the direction of specified LED.
    @param      None.
    @return     return code of ADI_A2B_SYS_LED_RESULT type
                    - ADI_A2B_SYS_LED_SUCCESS:  The API call is success.
                    - ADI_A2B_SYS_LED_FAILED :  The API call is failure.

    <b> Global Variables Used: <b>
                    None.

   @note        None.
 */

static ADI_A2B_SYS_RESULT LED_Init(void)
{
    ADI_A2B_HAL_GPIO_STATUS eGPIORes;

#ifdef __ADSPSC59x__
    eGPIORes =  adi_ss_hal_gpio_SetDirection(LED7_PORT, LED7_PIN, ADI_A2B_HAL_GPIO_DIRECTION_OUTPUT);
    if(eGPIORes != ADI_A2B_HAL_GPIO_STATUS_SUCCESS)
    {
        return ADI_A2B_SYS_FAILURE;
    }

    /*DAI pins are connected to LEDs on 21569 EZ KIT*/
	/* Initialize DAI for LED control */
	SRU(HIGH,DAI0_PBEN08_I);
	SRU(HIGH,DAI0_PBEN11_I);

	SRU(LOW,DAI0_PB08_I);
	SRU(LOW,DAI0_PB11_I);

#else

    eGPIORes =  adi_a2b_hal_gpio_SetDirection(LED10_PORT, LED10_PIN,ADI_A2B_HAL_GPIO_DIRECTION_OUTPUT);
    if(eGPIORes != ADI_A2B_HAL_GPIO_STATUS_SUCCESS)
    {
        return ADI_A2B_SYS_FAILURE;
    }

    eGPIORes =  adi_a2b_hal_gpio_SetDirection(LED11_PORT, LED11_PIN,ADI_A2B_HAL_GPIO_DIRECTION_OUTPUT);
    if(eGPIORes != ADI_A2B_HAL_GPIO_STATUS_SUCCESS)
    {
        return ADI_A2B_SYS_FAILURE;
    }

    eGPIORes =  adi_a2b_hal_gpio_SetDirection(LED12_PORT, LED12_PIN,ADI_A2B_HAL_GPIO_DIRECTION_OUTPUT);
    if(eGPIORes != ADI_A2B_HAL_GPIO_STATUS_SUCCESS)
    {
        return ADI_A2B_SYS_FAILURE;
    }

#ifdef __ADSPSC584__
    eGPIORes =  adi_a2b_hal_gpio_SetDirection(LED13_PORT, LED13_PIN,ADI_A2B_HAL_GPIO_DIRECTION_OUTPUT);
    if(eGPIORes != ADI_A2B_HAL_GPIO_STATUS_SUCCESS)
    {
        return ADI_A2B_SYS_FAILURE;
    }

    eGPIORes =  adi_a2b_hal_gpio_SetDirection(LED14_PORT, LED14_PIN,ADI_A2B_HAL_GPIO_DIRECTION_OUTPUT);
    if(eGPIORes != ADI_A2B_HAL_GPIO_STATUS_SUCCESS)
    {
        return ADI_A2B_SYS_FAILURE;
    }

    eGPIORes =  adi_a2b_hal_gpio_SetDirection(LED15_PORT, LED15_PIN,ADI_A2B_HAL_GPIO_DIRECTION_OUTPUT);
    if(eGPIORes != ADI_A2B_HAL_GPIO_STATUS_SUCCESS)
    {
        return ADI_A2B_SYS_FAILURE;
    }

    eGPIORes =  adi_a2b_hal_gpio_SetDirection(LED16_PORT, LED16_PIN,ADI_A2B_HAL_GPIO_DIRECTION_OUTPUT);
    if(eGPIORes != ADI_A2B_HAL_GPIO_STATUS_SUCCESS)
    {
        return ADI_A2B_SYS_FAILURE;
    }

    eGPIORes =  adi_a2b_hal_gpio_SetDirection(LED17_PORT, LED17_PIN,ADI_A2B_HAL_GPIO_DIRECTION_OUTPUT);
    if(eGPIORes != ADI_A2B_HAL_GPIO_STATUS_SUCCESS)
    {
        return ADI_A2B_SYS_FAILURE;
    }
#endif
#endif
    return ADI_A2B_SYS_SUCCESS;
}

 /*!
    @brief      This function updates the LED status.
    @param      eLEDNo      LED number.
    @param      bLEDState   Turn ON/OFF LED.
    @return     return code of ADI_A2B_SYS_LED_RESULT type
                    - ADI_A2B_SYS_LED_SUCCESS:  The API call is success.
                    - ADI_A2B_SYS_LED_FAILED :  The API call is failure.

    <b> Global Variables Used: <b>
                    None.

   @note        None.
 */
static ADI_A2B_SYS_RESULT LED_Update(ADI_A2B_SYS_LED_NO eLEDNo, bool bLEDOn)
{
    ADI_A2B_HAL_GPIO_PORT eGpioPort;
    ADI_A2B_HAL_GPIO_STATUS eGpioRes;
    ADI_A2B_HAL_GPIO_PIN nGpioPin;

    switch(eLEDNo)
    {
    case ADI_A2B_SYS_LED10:
        eGpioPort = LED10_PORT;
        nGpioPin = LED10_PIN;
        break;
    case ADI_A2B_SYS_LED11:
        eGpioPort = LED11_PORT;
        nGpioPin = LED11_PIN;
        break;
    case ADI_A2B_SYS_LED12:
        eGpioPort = LED12_PORT;
        nGpioPin = LED12_PIN;
        break;
#ifdef __ADSPSC584__
    case ADI_A2B_SYS_LED13:
        eGpioPort = LED13_PORT;
        nGpioPin = LED13_PIN;
        break;
    case ADI_A2B_SYS_LED14:
        eGpioPort = LED14_PORT;
        nGpioPin = LED14_PIN;
        break;
    case ADI_A2B_SYS_LED15:
        eGpioPort = LED15_PORT;
        nGpioPin = LED15_PIN;
        break;
    case ADI_A2B_SYS_LED16:
        eGpioPort = LED16_PORT;
        nGpioPin = LED16_PIN;
        break;
    case ADI_A2B_SYS_LED17:
        eGpioPort = LED17_PORT;
        nGpioPin = LED17_PIN;
        break;
#endif
    default:
        return ADI_A2B_SYS_FAILURE;
    }

    if(bLEDOn)
    {
        eGpioRes = adi_a2b_hal_gpio_Set(eGpioPort,nGpioPin);
    }
    else
    {
        eGpioRes = adi_a2b_hal_gpio_Clear(eGpioPort,nGpioPin);
    }

    return ((eGpioRes==ADI_A2B_HAL_GPIO_STATUS_SUCCESS)?ADI_A2B_SYS_SUCCESS:ADI_A2B_SYS_FAILURE);
}
#endif

void PADS_Init(void)
{
    *pREG_PADS0_DAI0_IE  = (uint32_t)0xffffffffU;
    *pREG_PADS0_DAI1_IE  = (uint32_t)0xffffffffU;

#ifdef __ADSPSC59x__
	*pREG_SPU0_SECUREP63=0x3;//DMA0(SPORT0A)
	*pREG_SPU0_SECUREP64=0x3;//DMA1(SPORT0B)

	*pREG_SPU0_SECUREP65=0x3;//DMA2(SPORT1A)
	*pREG_SPU0_SECUREP66=0x3;//DMA3(SPORT1B)
    *pREG_SPU0_SECUREP67=0x3;
    *pREG_SPU0_SECUREP68=0x3;
    *pREG_SPU0_SECUREP69=0x3;

    /* Enable secure transaction for SPORT DMA registers */
    *pREG_SPU0_SECUREP13=0x3;
    *pREG_SPU0_SECUREP14=0x3;
    *pREG_SPU0_SECUREP15=0x3;
    *pREG_SPU0_SECUREP16=0x3;
    *pREG_SPU0_SECUREP17=0x3;
    *pREG_SPU0_SECUREP18=0x3;

    *pREG_SPU0_SECUREP21=0x3;
    *pREG_SPU0_SECUREP22=0x3;
    *pREG_SPU0_SECUREP23=0x3;
    *pREG_SPU0_SECUREP24=0x3;

	*pREG_SPU0_SECUREP71=0x3;//(SPORT4A -- RX)
	*pREG_SPU0_SECUREP72=0x3;//(SPORT4B -- RX)
	*pREG_SPU0_SECUREP73=0x3;//DMA12(SPORT5A -- TX)
	*pREG_SPU0_SECUREP74=0x3;//DMA13(SPORT5B -- TX)

	*pREG_SPU0_SECUREP75=0x3;//DMA14(SPORT6A -- RX)
	*pREG_SPU0_SECUREP76=0x3;//DMA15(SPORT6B -- TX)
#else
    *pREG_SPU0_SECUREP23 = (uint32_t)0x3;         /*  SPORT 4A        */
    *pREG_SPU0_SECUREP15 = (uint32_t)0x3;         /*  SPORT 0A        */
    *pREG_SPU0_SECUREP25 = (uint32_t)0x3;         /*  SPORT 5A        */
    *pREG_SPU0_SECUREP17 = (uint32_t)0x3;         /*  SPORT 1A        */

    *pREG_SPU0_SECUREP74 = (uint32_t)0x3;         /*  SPORT 4A DMA10  */
    *pREG_SPU0_SECUREP66 = (uint32_t)0x3;         /*  SPORT 0A DMA0  */
    *pREG_SPU0_SECUREP76 = (uint32_t)0x3;         /*  SPORT 5A DMA12  */
    *pREG_SPU0_SECUREP68 = (uint32_t)0x3;         /*  SPORT 1A DMA2  */

    *pREG_SPU0_SECUREP88 = (uint32_t)0x3;         /*  MDMA0 SRC DMA8  */
    *pREG_SPU0_SECUREP89 = (uint32_t)0x3;         /*  MDMA0 DST DMA9  */
    *pREG_SPU0_SECUREP90 = (uint32_t)0x3;         /*  MDMA1 SRC DMA18 */
    *pREG_SPU0_SECUREP91 = (uint32_t)0x3;         /*  MDMA1 DST DMA19 */
#endif
}

/*!
   @brief        This function does the address translation for the given L1 mem address based on the SHARC ID.
   @param        nMemAddr            L1 Memory address which has to be translated
   @param        eProcID             PROCESSOR ID (only for SHARCS)
   @param        IsGetId             Boolean flag indicating whether to read the processor ID or use passed
                                     eProcID for address translation.
   @return       Translated address
   <b> Global Variables Used: <b>
                None

  @note            None.
*/

uint32 adi_a2b_address_translation(uint32 nMemAddr, ADI_A2B_PROC_ID eProcID, bool IsGetId)
{
    uint32_t result = nMemAddr;
    uint32_t nProcId;

    /* Address translation only applies to SHARC processors */

    if(IsGetId)
    {
    	nProcId = adi_core_id();
    }
    else
    {
    	nProcId = (uint32_t) eProcID;
    }

    /* IF (Supplied memory address is in L1) */
    if ((nMemAddr >= ADI_SC589_SHARC_L1_START_ADDR) && (nMemAddr <= ADI_SC589_SHARC_L1_END_ADDR))
    {
        /* IF (SHARC Core 0) */
        if (nProcId == PROCESSOR_SH0)
        {
            result = (nMemAddr | ADI_SC589_SHARC1_L1_SLAVE1_OFFSET);
        }
        /* ELSE IF (SHARC Core 1) */
        else if (nProcId == PROCESSOR_SH1)
        {
            result = (nMemAddr | ADI_SC589_SHARC2_L1_SLAVE1_OFFSET);
        }
        else
        {
        	result = nMemAddr;
        }
    }
    /* ELSE (Supplied address could be L2 or L3) */
    else
    {
    	result = nMemAddr;
    }

    return result;
}

/*
 *
 * EOF: $URL: https://dspeng.spd.analog.com/svn/sqe/stage/auto/a2bstacklinux/branches/19.9.0/kit/Target/examples/demo/a2b-linux/a2b-adsp-sc598-linux/a2b-app_Core1/src/adi_a2b_sys.c $
 *
*/
